@@ -1,10 +1,11 @@
 from .move import *
+from .sub import *
 
 __copyright__    = 'Copyright (C) 2021 igtm'
-__version__      = '0.0.2'
+__version__      = '0.0.4'
 __license__      = 'MIT'
 __author__       = 'igtm'
 __author_email__ = 'tomo14916253@yahoo.co.jp'
 __url__          = 'http://github.com/igtm/move_jismeshcode'
 
-__all__ = ['move']
\ No newline at end of file
+__all__ = ['move', 'sub']
\ No newline at end of file
